@@ -261,8 +261,8 @@ class LsiModel(interfaces.TransformationABC):
     Model persistency is achieved via its load/save methods.
     
     """
-    def __init__(self, corpus = None, numTopics = 200, id2word = None, chunks = 20000, 
-                 decay = 1.0, distributed = False, onepass = False):
+    def __init__(self, corpus=None, numTopics=200, id2word=None, chunks=20000, 
+                 decay=1.0, distributed=False, onepass=False):
         """
         `numTopics` is the number of requested factors (latent dimensions). 
         
@@ -278,8 +278,7 @@ class LsiModel(interfaces.TransformationABC):
         If your document stream is one-pass only (the stream cannot be repeated),
         turn on `onepass` to force a single pass SVD algorithm (slower).
 
-        Turn on `distributed` to enforce distributed computing (only makes sense 
-        if `onepass` is set at the same time, too).
+        Turn on `distributed` to force distributed computing.
         
         Example:
         
@@ -322,7 +321,8 @@ class LsiModel(interfaces.TransformationABC):
             try:
                 import Pyro
                 ns = Pyro.naming.locateNS()
-                dispatcher = Pyro.core.Proxy('PYRONAME:gensim.dispatcher@%s' % ns._pyroUri.location)
+                dispatcher = Pyro.core.Proxy('PYRONAME:gensim.lsi_dispatcher@%s' % ns._pyroUri.location)
+                dispatcher._pyroOneway.add("exit")
                 logger.debug("looking for dispatcher at %s" % str(dispatcher._pyroUri))
                 dispatcher.initialize(id2word = self.id2word, numTopics = numTopics, 
                                       chunks = chunks, decay = decay,
@@ -338,7 +338,7 @@ class LsiModel(interfaces.TransformationABC):
             self.addDocuments(corpus)
     
     
-    def addDocuments(self, corpus, chunks = None, decay = None):
+    def addDocuments(self, corpus, chunks=None, decay=None):
         """
         Update singular value decomposition to take into account a new 
         corpus of documents.
@@ -390,15 +390,10 @@ class LsiModel(interfaces.TransformationABC):
                         logger.info("processed documents up to #%s" % doc_no)
                         self.printTopics(5) # TODO see if printDebug works and remove one of these..
                 
+                # wait for all workers to finish (distributed version only)
                 if self.dispatcher:
                     logger.info("reached the end of input; now waiting for all remaining jobs to finish")
-                    import time
-                    while self.dispatcher.jobsdone() <= chunk_no:
-                        time.sleep(0.5) # check every half a second
-                    logger.info("all jobs finished, downloading final projection")
-                    del self.projection
                     self.projection = self.dispatcher.getstate()
-                    logger.info("decomposition complete")
         else:
             assert not self.dispatcher, "must be in serial mode to receive jobs"
             assert self.onepass, "distributed two-pass algo not supported yet"
@@ -426,10 +421,10 @@ class LsiModel(interfaces.TransformationABC):
         # if the input vector is in fact a corpus, return a transformed corpus as result
         is_corpus, bow = utils.isCorpus(bow)
         if is_corpus:
-            self._apply(bow)
+            return self._apply(bow)
         
         assert self.projection.u is not None, "decomposition not initialized yet"
-        vec = numpy.asfortranarray(matutils.sparse2full(bow, self.numTerms), dtype = self.projection.u.dtype)
+        vec = matutils.sparse2full(bow, self.numTerms).astype(self.projection.u.dtype)
         vec.shape = (self.numTerms, 1)
         topicDist = scipy.linalg.fblas.dgemv(1.0, self.projection.u, vec, trans = True) # u^T * x
         if scaled:
@@ -696,8 +691,8 @@ def stochasticSvd(corpus, rank, num_terms=None, chunks=20000, extra_dims=None, d
     in case the input is of lower rank. Also note that the decomposition is unique
     up the the sign of the left singular vectors (columns of U).
     
-    This is a streamed, two-pass algorithm, without power-itrations. In case you can 
-    only afford a single pass over the input corpus, set onepass=True in LsiModel and 
+    This is a streamed, two-pass algorithm, without power-iterations. In case you can 
+    only afford a single pass over the input corpus, set `onepass=True` in LsiModel and 
     avoid using this algorithm.
 
     The decomposition algorithm is based on 
